# StrongDoc Python SDK by StrongSalt
This is a Python SDK for the [StrongDoc](https://api.strongsalt.com "Strongdoc API") service, produced by StrongSalt. The API endpoint for Python clients of Strongdoc is implemented with gRPC.

## Important Links

Documentation: [ReadTheDocs](https://strongdoc-python-sdk.readthedocs.io/en/latest/)

Website: [strongsalt.com](https://www.strongsalt.com "Strongsalt website")

## Installation

The API is available as a Python Package. You must first do:

`pip install strongsalt-strongdoc-python-sdk==0.0.2`

Then, import it into your files at the top of your files:

```
from strongdoc.api import account, document, login, search
```
